@@ -18,30 +18,30 @@
 ##
 
 import sys
+from typing import List
 
 import marshmallow_dataclass
-
-from aceql._private.file_util import FileUtil
-from aceql._private.parms import Parms
-from aceql._private.user_login_store import UserLoginStore
-from aceql._private.jdbc_database_meta_data_dto import JdbcDatabaseMetaDataDto
-from aceql._private.table_dto import TableDto
-from aceql._private.table_names_dto import TableNamesDto
-
 import requests
 from requests_toolbelt.multipart import encoder
 
-from aceql._private.file_util import os
-from aceql.error import Error
-from aceql.connection_options import ConnectionOptions
-from aceql.progress_indicator import ProgressIndicator
-from aceql.proxy_auth import ProxyAuth
 from aceql._private.aceql_debug import AceQLDebug
+from aceql._private.batch.update_counts_array_dto import UpdateCountsArrayDto
+from aceql._private.file_util import FileUtil
+from aceql._private.file_util import os
+from aceql._private.dto.jdbc_database_meta_data_dto import JdbcDatabaseMetaDataDto
+from aceql._private.aceql_debug_parms import AceQLDebugParms
 from aceql._private.result_analyzer import ResultAnalyzer
 from aceql._private.result_set_info import ResultSetInfo
 from aceql._private.row_counter import RowCounter
 from aceql._private.stream_result_analyzer import StreamResultAnalyzer
+from aceql._private.dto.table_dto import TableDto
+from aceql._private.dto.table_names_dto import TableNamesDto
+from aceql._private.user_login_store import UserLoginStore
 from aceql._private.version_values import VersionValues
+from aceql.connection_options import ConnectionOptions
+from aceql.error import Error
+from aceql.progress_indicator import ProgressIndicator
+from aceql.proxy_auth import ProxyAuth
 
 
 class AceQLHttpApi(object):
@@ -178,7 +178,8 @@ class AceQLHttpApi(object):
     def call_with_get_action(self, action: str, action_parameter: dict) -> str:
         url_withaction = self._url + action
 
-        #self.debug(str("url_withaction: " + url_withaction))
+        if AceQLHttpApi.__debug:
+            print("url_withaction: " + url_withaction)
 
         if action_parameter is not None and len(action_parameter) > 1:
             url_withaction += "/" + action_parameter
@@ -476,14 +477,14 @@ class AceQLHttpApi(object):
 
             if statement_parameters is not None:
                 if not isinstance(statement_parameters, dict):
-                    raise TypeError("statement_parameters is not a dictionnary!")
+                    raise TypeError("statement_parameters is not a dictionary!")
 
                 dict_params.update(statement_parameters)
 
             AceQLDebug.debug("dictParams 2: " + str(dict_params))
 
             # r = requests.post('http://httpbin.org/post', data = {'key':'value'})
-            # debug("Before update request")
+            # print("Before update request")
 
             if self.__timeout is None:
                 response = requests.post(url_withaction, headers=self.__headers, data=dict_params,
@@ -550,7 +551,7 @@ class AceQLHttpApi(object):
 
             if statement_parameters is not None:
                 if not isinstance(statement_parameters, dict):
-                    raise TypeError("statementParameters is not a dictionnary!")
+                    raise TypeError("statementParameters is not a dictionary!")
 
                 dict_params.update(statement_parameters)
 
@@ -593,14 +594,14 @@ class AceQLHttpApi(object):
         if self.is_gzip_result():
             file_out = filename[0: len(filename) - 4] + ".ungzipped.txt"
             FileUtil.decompress(filename, file_out)
-            if Parms.DELETE_FILES:
+            if AceQLDebugParms.DELETE_FILES:
                 os.remove(filename)
         else:
             file_out = filename
         AceQLDebug.debug("Before StreamResultAnalyzer")
         result_analyzer = StreamResultAnalyzer(file_out, self.__http_status_code)
         if not result_analyzer.is_status_ok():
-            if Parms.DELETE_FILES:
+            if AceQLDebugParms.DELETE_FILES:
                 os.remove(filename)
             raise Error(result_analyzer.get_error_message(),
                         result_analyzer.get_error_type(), None, None, self.__http_status_code)
@@ -787,13 +788,15 @@ class AceQLHttpApi(object):
                 raise Error(result_analyzer.get_error_message(),
                             result_analyzer.get_error_type(), None, None, self.__http_status_code)
 
-            self.debug(result)
+            if AceQLHttpApi.__debug:
+                print(result)
 
             holder_jdbc_database_meta_data_schema = marshmallow_dataclass.class_schema(JdbcDatabaseMetaDataDto)
             jdbc_database_meta_data_holder: JdbcDatabaseMetaDataDto = holder_jdbc_database_meta_data_schema().loads(
                 result)
 
-            self.debug(jdbc_database_meta_data_holder)
+            if AceQLHttpApi.__debug:
+                print(jdbc_database_meta_data_holder)
 
             return jdbc_database_meta_data_holder;
 
@@ -817,12 +820,14 @@ class AceQLHttpApi(object):
                 raise Error(result_analyzer.get_error_message(),
                             result_analyzer.get_error_type(), None, None, self.__http_status_code)
 
-            self.debug(result)
+            if AceQLHttpApi.__debug:
+                print(result)
 
             table_names_dto_schema = marshmallow_dataclass.class_schema(TableNamesDto)
             table_names_dto: TableNamesDto = table_names_dto_schema().loads(result)
 
-            self.debug(table_names_dto)
+            if AceQLHttpApi.__debug:
+                print(table_names_dto)
 
             return table_names_dto;
 
@@ -842,7 +847,8 @@ class AceQLHttpApi(object):
 
             result = self.call_with_get_url(url_withaction)
 
-            self.debug(result)
+            if AceQLHttpApi.__debug:
+                print(result)
 
             result_analyzer = ResultAnalyzer(result, self.__http_status_code)
             if not result_analyzer.is_status_ok():
@@ -852,7 +858,8 @@ class AceQLHttpApi(object):
             table_dto_schema = marshmallow_dataclass.class_schema(TableDto)
             table_dto: TableDto = table_dto_schema().loads(result)
 
-            self.debug(table_dto)
+            if AceQLHttpApi.__debug:
+                print(table_dto)
 
             return table_dto;
 
@@ -868,6 +875,56 @@ class AceQLHttpApi(object):
     def reset_request_headers(self):
         self.__headers = {}
 
-    def debug(param):
-        if AceQLHttpApi.__debug:
-            print(str(param))
\ No newline at end of file
+    def execute_batch(self, sql: str, batch_file_parameters: str):
+
+        try:
+            action = "prepared_statement_execute_batch"
+            AceQLHttpApi.check_values(True, sql)
+            url_withaction = self._url + action
+
+            AceQLDebug.debug("url_withaction: " + url_withaction)
+
+            blob_id: str = os.path.basename(batch_file_parameters)
+            length: int = os.path.getsize(batch_file_parameters)
+
+            with open(batch_file_parameters, "rb") as fd:
+                self.blob_upload(blob_id, fd, length)
+
+            dict_params: dict = {"sql": sql, "blob_id": blob_id}
+            AceQLDebug.debug("dict_params: " + str(dict_params))
+
+            # r = requests.post('http://httpbin.org/post', data = {'key':'value'})
+            # print("Before update request")
+
+            if self.__timeout is None:
+                response = requests.post(url_withaction, headers=self.__headers, data=dict_params,
+                                         proxies=self.__proxies, auth=self.__auth)
+            else:
+                response = requests.post(url_withaction, headers=self.__headers, data=dict_params,
+                                         proxies=self.__proxies, auth=self.__auth,
+                                         timeout=self.__timeout)
+
+            self.__http_status_code = response.status_code
+            result = response.text
+
+            # print("self.__http_status_code: " + str(self.__http_status_code ))
+            # print("result                 : " + str(result))
+            AceQLDebug.debug("result: " + result)
+
+            result_analyzer = ResultAnalyzer(result, self.__http_status_code)
+            if not result_analyzer.is_status_ok():
+                raise Error(result_analyzer.get_error_message(),
+                            result_analyzer.get_error_type(), None, None, self.__http_status_code)
+
+            update_counts_array_dto_schema = marshmallow_dataclass.class_schema(UpdateCountsArrayDto)
+            update_counts_array_dto_back: UpdateCountsArrayDto = update_counts_array_dto_schema().loads(
+                result)
+
+            update_counts_array: List[int] = update_counts_array_dto_back.updateCountsArray
+            return update_counts_array
+        except Exception as e:
+            if isinstance(e, Error):
+                raise
+            else:
+                raise Error(str(e), 0, e, None, self.__http_status_code)
+
