@@ -1,7 +1,7 @@
 #
 # This file is part of AceQL Python Client SDK.
 # AceQL Python Client SDK: Remote SQL access over HTTP with AceQL HTTP.
-# Copyright (C) 2020,  KawanSoft SAS
+# Copyright (C) 2021,  KawanSoft SAS
 # (http://www.kawansoft.com). All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -43,7 +43,8 @@ class DateTimeUtil(object):
     # get_timestamp_from_datetime = staticmethod(get_timestamp_from_datetime)
 
     @staticmethod
-    def to_timestamp(a_date):
+    def to_timestamp(a_date: str) -> int:
+        """"Returns a timestamp for a str date."""
         if a_date.tzinfo:
             epoch = datetime(1970, 1, 1, tzinfo=pytz.UTC)
             diff = a_date.astimezone(pytz.UTC) - epoch
@@ -53,16 +54,16 @@ class DateTimeUtil(object):
         return int(diff.total_seconds())
 
     @staticmethod
-    def get_timestamp_from_date(the_date):
+    def get_timestamp_from_date(the_date: datetime) -> str:
         """"Returns an Epoch for date."""
-        unix_time = time.mktime(the_date.timetuple())
 
+        unix_time = time.mktime(the_date.timetuple())
         unix_time_str = str(unix_time)
         unix_time_str = unix_time_str[0:len(unix_time_str) - 2]
         return unix_time_str + "000"
 
     @staticmethod
-    def get_datetime_from_timestamp(ts_str):
+    def get_datetime_from_timestamp(ts_str : str) -> datetime:
         """Returns a datetime from Unix Epoch."""
 
         ts = float(ts_str)
@@ -70,7 +71,7 @@ class DateTimeUtil(object):
         return datetime.fromtimestamp(ts_int)
 
     @staticmethod
-    def get_date_from_timestamp(ts_str):
+    def get_date_from_timestamp(ts_str : str) -> datetime:
         """Returns a date from Unix Epoch."""
 
         ts = float(ts_str)
@@ -79,7 +80,7 @@ class DateTimeUtil(object):
         return the_datetime.date()
 
     @staticmethod
-    def get_time_from_timestamp(ts_str):
+    def get_time_from_timestamp(ts_str: str) -> datetime:
         """Returns a date from Unix Epoch."""
 
         ts = float(ts_str)
