@@ -16,12 +16,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 ##
+from typing import List
 
+import marshmallow_dataclass
+
+from aceql._private.batch.prep_statement_params_holder import PrepStatementParametersHolder
+from aceql._private.file_util import FileUtil
 from aceql._private.row_parser import RowParser
 from aceql._private.cursor_util import CursorUtil
 from aceql._private.datetime_util import DateTimeUtil
 from aceql._private.aceql_http_api import AceQLDebug, Error, os, AceQLHttpApi
-from aceql._private.parms import Parms
+from aceql._private.aceql_debug_parms import AceQLDebugParms
 
 
 class Cursor(object):
@@ -36,7 +41,7 @@ class Cursor(object):
         self.__description = []
 
         self.__filelist = []
-        self.arraysize = 1
+        self.__arraysize = 1
 
         self.__row_parser = None
 
@@ -70,7 +75,7 @@ class Cursor(object):
         return sql
 
     def execute(self, sql: str, params: tuple = ()):
-        """Executes the given operation
+        """Executes the given SQL operation
 
         Executes the given operation substituting any markers with
         the given parameters.
@@ -90,13 +95,53 @@ class Cursor(object):
         else:
             return self.__execute_update(sql, params)
 
-    def executemany(self):
-        """Execute the given operation multiple times.
-
-        Not implemented in this version.
+    def executemany(self, sql: str, seq_params: list) -> List[int]:
+        """Execute the given SQL operation multiple times
+        The executemany() method will execute the operation iterating
+        over the list of parameters in seq_params.
+        Note that the SQL operation are transferred with one unique HTTP call to the server side which will execute
+        them using a JDBC PreparedStatement in batch mode: this will allow fast execution.
         """
-        self.__raise_error_if_closed()
-        raise NotImplementedError("executemany is not implemented in this AceQL SDK version.")
+        batch_file_parameters = FileUtil.build_batch_file()
+
+        try:
+            self.__raise_error_if_closed()
+
+            if sql is None:
+                raise TypeError("sql is null!")
+
+            sql = sql.strip()
+
+            if not CursorUtil.is_update_call(sql):
+                raise Error("Only DELETE, INSERT or UPDATE calls are supported this AceQL Client version.", 0,
+                            None, None, 200)
+
+            if not seq_params:
+                return
+
+            # The addBatch() part
+            for params in seq_params:
+                the_cursor_util: CursorUtil = CursorUtil()
+                parms_dict: dict = the_cursor_util.get_http_parameters_dict(params)
+
+                blob_ids: list = the_cursor_util.blob_ids
+                if blob_ids is not None and len(blob_ids) > 0:
+                    raise Error("Cannot call executemany for a table with BLOB parameter in this AceQL Client version.", 0,
+                                None, None, 200)
+
+                prep_statement_parameters_holder_schema = marshmallow_dataclass.class_schema(
+                    PrepStatementParametersHolder)
+                prep_statement_parameters_holder: PrepStatementParametersHolder = PrepStatementParametersHolder(
+                    parms_dict)
+                json_string: str = prep_statement_parameters_holder_schema().dumps(prep_statement_parameters_holder)
+                with open(batch_file_parameters, "a") as fd:
+                    fd.write(json_string + "\n")
+
+            # The executeBatch() part
+            rows: List[int] = self.__aceql_http_api.execute_batch(sql, batch_file_parameters)
+            return rows
+        finally:
+            os.remove(batch_file_parameters)
 
     def __execute_update(self, sql: str, params: tuple = ()) -> int:
         """Executes and update operation on remote database"""
@@ -104,8 +149,8 @@ class Cursor(object):
         blob_streams: list = []
 
         try:
-            the_cursor_util = CursorUtil()
-            parms_dict = the_cursor_util.get_http_parameters_dict(params)
+            the_cursor_util: CursorUtil = CursorUtil()
+            parms_dict: dict = the_cursor_util.get_http_parameters_dict(params)
 
             blob_ids = the_cursor_util.blob_ids
             blob_streams = the_cursor_util.blob_streams
@@ -122,14 +167,14 @@ class Cursor(object):
             if len(parms_dict) > 0:
                 is_prepared_statement = True
 
-            rows:int = self.__aceql_http_api.execute_update(sql, is_prepared_statement, parms_dict)
+            rows: int = self.__aceql_http_api.execute_update(sql, is_prepared_statement, parms_dict)
             self.__rowcount = rows
             return rows
         finally:
             for blob_stream in blob_streams:
                 blob_stream.close()
 
-    def __execute_query(self, sql: str, params: tuple =()):
+    def __execute_query(self, sql: str, params: tuple = ()):
         """Executes a SELECT on remote database"""
         self.__raise_error_if_closed()
 
@@ -171,14 +216,14 @@ class Cursor(object):
         values_per_column_index = self.__row_parser.get_values_per_col_index()
         types_per_column_index = self.__row_parser.get_types_per_col_index()
 
-        if Parms.DEBUG_ON:
+        if AceQLDebugParms.DEBUG_ON:
             print("values_per_column_index: " + str(values_per_column_index))
             print("types_per_column_index : " + str(types_per_column_index))
 
         the_list = []
         index = 0
         for k, v in values_per_column_index.items():
-            if Parms.DEBUG_ON:
+            if AceQLDebugParms.DEBUG_ON:
                 print(k, v)
             # detect Epoch timestamp and convert them to date for DATE and datetime for
             # TIMESTAMP
@@ -218,7 +263,7 @@ class Cursor(object):
         self.__raise_error_if_closed()
         size_to_use = size
         if size_to_use <= 1:
-            size_to_use = self.arraysize
+            size_to_use = self.__arraysize
 
         list_tuples: list[tuple] = []
         cpt = 0
@@ -270,7 +315,7 @@ class Cursor(object):
         row_parser: RowParser = None
 
         try:
-            row_parser  = RowParser(self.__result_set_info.get_filename(), self.__rowcount)
+            row_parser = RowParser(self.__result_set_info.get_filename(), self.__rowcount)
             row_parser.build_next_row()  # read first row to get the column names, only way to do it...
 
             aceql_types: dict = row_parser.get_types_per_col_index()
@@ -337,8 +382,7 @@ class Cursor(object):
                         0, None, None, 200)
 
         blob_id = values_per_column_index[column_index]
-        if Parms.DEBUG_ON:
-            print("blob_id: " + str(blob_id))
+        print("blob_id: " + str(blob_id))
 
         Cursor.check_blob_id(blob_id, column_index)
         blob_length = self.__aceql_http_api.get_blob_length(blob_id)
@@ -379,7 +423,7 @@ class Cursor(object):
         if self.__row_parser is not None:
             self.__row_parser.close()  # very important
 
-        if Parms.DELETE_FILES:
+        if AceQLDebugParms.DELETE_FILES:
             for filename in self.__filelist:
                 os.remove(filename)
 
